#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-metrics
version:              0.3.3
visibility:           public
id:                   text-metrics-0.3.3-4fsxFF1wzFH6gL72N3n6o2
key:                  text-metrics-0.3.3-4fsxFF1wzFH6gL72N3n6o2
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/text-metrics
synopsis:             Calculate various string metrics efficiently
description:          Calculate various string metrics efficiently.
category:             Text, Algorithms
abi:                  3e78a04b37df39490cc3382c9c0b92ea
exposed:              True
exposed-modules:      Data.Text.Metrics
import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-metrics-0.3.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-metrics-0.3.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-metrics-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-metrics
hs-libraries:         HStext-metrics-0.3.3-4fsxFF1wzFH6gL72N3n6o2
depends:
    base-4.18.2.1 containers-0.6.7
    primitive-0.9.1.0-CNGLkGw87wIklpcGUTNYD text-2.0.2
    vector-0.13.2.0-2P3Vv0GFH0i4NgSchvbpWK

haddock-interfaces:
    /usr/share/doc/haskell-text-metrics/html/text-metrics.haddock

haddock-html:         /usr/share/doc/haskell-text-metrics/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

